number of people employed in agriculture (crop+livestock production)
Arguments
- datasource
ILO for reporting aggregated employment in crop+livestock production, or ILO_FAO, which uses the same aggregated employment data from ILO, but applies FAO value of production shares to disaggregated between employment in crop and in livestock production.
- dataVersionILO
"" for the oldest version, or "monthYear" (e.g. "Aug23") for a newer version