Skip to content

calculates the validation data for production of grass from managed pastures and rangelands separetely

Usage

calcValidGrassLSUha(datasource = "MAgPIEown")

Arguments

datasource

Currently available: "MAgPIEown"

Value

List of magpie objects with results on country level, weight on country level, unit and description.

See also

Author

Marcos Alves

Examples

if (FALSE) { # \dontrun{
calcOutput("ValidGrassLSUha")
} # }