Skip to content

reports Cropland Nitrogen Withdrawals from soils on 0.5 degree grid

Usage

calcValidGridCroplandNitrogenWithdrawals(irrigation = FALSE)

Arguments

irrigation

FALSE for the sum of irrigated and rainfed, FALSE for seperated categories, 'rainfed' or 'irrigated for single categories

Value

List of magpie objects with results on cellular level, weight on cellular level, unit and description.

Author

Benjamin Leon Bodirsky

Examples


if (FALSE) { # \dontrun{ 
calcOutput("ValidGridCroplandNitrogenWithdrawals")
} # }