calculates the validation data for calorie food supply
Arguments
- datasource
Datasource of validation data. If "FAO", we use FAO calories with FAO population data (slightly diverges from original data as the convert script for example splits up countries for the past). If "FAOmassbalance" we use calories from the FAO massbalance calculations, and divide them by our standard population.
- nutrient
kcal or protein
- detail
if FALSE, only larger product categories are reported
Value
List of magpie objects with results on country level, weight on country level, unit and description.