Skip to content

Validates the esitmates on excretion and manure management

Usage

calcValidManure(datasource = "Bodirsky")

Arguments

datasource

own: own estimation for the past based on feed intake, IPCC: standard excretion factors, FAO: FAO estimates

Value

List of magpie objects with results on country level, weight on country level, unit and description.

Author

Benjamin Leon Bodirsky

Examples


if (FALSE) { # \dontrun{
calcOutput("ValidManure")
} # }