calculates the validation data for the share of inputs that go into processing processes, and the share of inputs that secondary products are composed of
Usage
calcValidProcessing(
datasource = "FAO",
detail = TRUE,
nutrient = "dm",
indicator = "primary_to_process"
)Arguments
- datasource
Datasource of validation data.
- detail
if FALSE, only larger product categories are reported
- nutrient
The nutrient in which the results shall be reported.
- indicator
if "primary_to_process", returns the amount of primary product into processing. if "secondary_from_primary", gives primary into secondary.
Value
List of magpie objects with results on country level, weight on country level, unit and description.