Skip to content

calculates the validation data for the soil carbon densities (including weights for aggregation)

Usage

calcValidSOCDensity(datasource = "GSOC")

Arguments

datasource

Datasources for validation data

Value

List of magpie objects with results on country level, weight on country level, unit and description.

Author

Kristine Karstens

Examples

if (FALSE) { # \dontrun{
calcOutput("ValidSOCDensity")
} # }