Skip to content

calculates the validation data for the soil carbon shares

Usage

calcValidSOCShare(datasource = "histSOCbudget")

Arguments

datasource

Datasources only "histSOCbudget"

Value

List of magpie objects with results on country level, weight on country level, unit and description.

Author

Kristine Karstens

Examples

if (FALSE) { # \dontrun{
calcOutput("ValidSOCShare")
} # }