Skip to content

Convert data on agricultural water use Convert subtypes on ISO country level.

Usage

convertWaterUsage(x, subtype)

Arguments

x

MAgPIE object containing IrrigatedArea data on Country level

subtype

: No subtype needed

Value

Data on water use as MAgPIE object on country level Missing values are added as NA

See also

Author

Stephen Wirth

Examples

if (FALSE) { # \dontrun{
a <- readSource("WaterUsage", "aquastat_2008_12")
} # }