Skip to content

Function that produces the complete validation data set used for evaluation of MAgPIE outputs

Usage

fullVALIDATION(rev = 0.1, aggregate = "region+global")

Arguments

rev

data revision which should be used as input. Will be converted to numeric_version when called via retrieveData.

aggregate

an aggregation level, such as "region+global", to be used for all outputs that are being aggregated.

Author

Jan Philipp Dietrich, Benjamin Leon Bodirsky

Examples

if (FALSE) { # \dontrun{
retrieveData("Validation")
} # }