Skip to content

read the Global Carbon Budget, selecting the models GCB, BLUE, H&C2023, OSCAR and their sub-components Net, Deforestation, Forest regrowth, Other transitions, Wood harvest and other forest management, plus GCB's peat drainage & peat fires (the only model reporting peat) as a common peat term

Usage

readGlobalCarbonBudget()

Value

a magpie object in Mt CO2 per year

Author

Michael Crawford, Florian Humpenoeder

Examples

if (FALSE) { # \dontrun{
readSource("GlobalCarbonBudget")
} # }