R/calcValidLand.R
calcValidLand.Rd
Returns historical cropland, pasture and forest area from FAOSTAT that can be used for model validation.
calcValidLand(datasource = "MAgPIEown")
Currently available: "FAO", "LUH2v2", "LUH3", "MAgPIEown" and "SSPResults"
"FAO"
"LUH2v2"
"LUH3"
"MAgPIEown"
"SSPResults"
list of magpie object with data and weight
Ulrich Kreidenweis, Benjamin Bodirsky, Abhijeet Mishra, Mishko Stevanovic, Kristine Karstens