calcValidLivestockDemStructure
Source:R/calcValidLivestockDemStructure.R
calcValidLivestockDemStructure.Rdcalculates the validation data for the share of different livestock products (excluding fish) in total livestock calorie food supply
Value
List of magpie objects with results on country level, weight on country level, unit and description.