Function that produces the complete validation data set used for evaluation of MAgPIE outputs
Arguments
- rev
data revision which should be used as input. Will be converted to
numeric_versionwhen called viaretrieveData.- aggregate
an aggregation level, such as "region+global", to be used for all outputs that are being aggregated.