Skip to content

read the Global Carbon Budget, selecting the models GCB, BLUE, H&C2023, OSCAR and their sub-components Net, Deforestation, Forest regrowth, Other transitions, Wood harvest and other forest management

Usage

readGlobalCarbonBudget()

Value

a magpie object in Mt CO2 per year

Author

Michael Crawford

Examples

if (FALSE) { # \dontrun{
readSource("GlobalCarbonBudget")
} # }