read World Bank poverty percentage of population under poverty line, and gini coef data No download function from WDI API yet, as the older versions (2011PPP as opposed to 2017PPP online) are currently most relevant for validating Soergel poverty model results and must be downloaded manually